==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectPatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterEnvoyConfigObjectPatchBuilder extends EnvoyFilterEnvoyConfigObjectPatchFluentImpl<EnvoyFilterEnvoyConfigObjectPatchBuilder> implements VisitableBuilder<EnvoyFilterEnvoyConfigObjectPatch,EnvoyFilterEnvoyConfigObjectPatchBuilder>{
  public EnvoyFilterEnvoyConfigObjectPatchBuilder() {
    this(false);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterEnvoyConfigObjectPatch(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterEnvoyConfigObjectPatch(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatchFluent<?> fluent,EnvoyFilterEnvoyConfigObjectPatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatchFluent<?> fluent,EnvoyFilterEnvoyConfigObjectPatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApplyTo(instance.getApplyTo());
      fluent.withMatch(instance.getMatch());
      fluent.withPatch(instance.getPatch());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatch instance) {
    this(instance,false);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApplyTo(instance.getApplyTo());
      this.withMatch(instance.getMatch());
      this.withPatch(instance.getPatch());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterEnvoyConfigObjectPatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterEnvoyConfigObjectPatch build() {
    EnvoyFilterEnvoyConfigObjectPatch buildable = new EnvoyFilterEnvoyConfigObjectPatch(fluent.getApplyTo(),fluent.getMatch(),fluent.getPatch());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectPatchBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterEnvoyConfigObjectPatchBuilder extends EnvoyFilterEnvoyConfigObjectPatchFluent<EnvoyFilterEnvoyConfigObjectPatchBuilder> implements VisitableBuilder<EnvoyFilterEnvoyConfigObjectPatch,EnvoyFilterEnvoyConfigObjectPatchBuilder>{
  public EnvoyFilterEnvoyConfigObjectPatchBuilder() {
    this(false);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterEnvoyConfigObjectPatch(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatchFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatchFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterEnvoyConfigObjectPatch(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatchFluent<?> fluent,EnvoyFilterEnvoyConfigObjectPatch instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatchFluent<?> fluent,EnvoyFilterEnvoyConfigObjectPatch instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectPatch());

    if (instance != null) {
      fluent.withApplyTo(instance.getApplyTo());
      fluent.withMatch(instance.getMatch());
      fluent.withPatch(instance.getPatch());
      fluent.withApplyTo(instance.getApplyTo());
      fluent.withMatch(instance.getMatch());
      fluent.withPatch(instance.getPatch());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatch instance) {
    this(instance,false);
  }
  public EnvoyFilterEnvoyConfigObjectPatchBuilder(EnvoyFilterEnvoyConfigObjectPatch instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectPatch());

    if (instance != null) {
      this.withApplyTo(instance.getApplyTo());
      this.withMatch(instance.getMatch());
      this.withPatch(instance.getPatch());
      this.withApplyTo(instance.getApplyTo());
      this.withMatch(instance.getMatch());
      this.withPatch(instance.getPatch());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterEnvoyConfigObjectPatchFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterEnvoyConfigObjectPatch build() {
    EnvoyFilterEnvoyConfigObjectPatch buildable = new EnvoyFilterEnvoyConfigObjectPatch(fluent.getApplyTo(),fluent.buildMatch(),fluent.buildPatch());
    return buildable;
  }
  
}
